FileExceptionHandlingModel class

Constructors

FileExceptionHandlingModel({bool fileTooLarge = false, bool notAllowedFormat = false, bool fileWrongDimensions = false, bool imageWrongRatio = false})

Properties

fileTooLarge bool
getter/setter pair
fileWrongDimensions bool
getter/setter pair
hasExceptions bool
no setter
hashCode int
The hash code for this object.
no setterinherited
imageWrongRatio bool
getter/setter pair
notAllowedFormat bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emptyExistingExceptions() → void
to reset all a one place
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFileTooLarge() → void
onNotAllowedFile() → void
onWrongDimensionsFile() → void
onWrongRatioImage() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited