FileExtension class

Constructors

FileExtension()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getFileExtensionFromUint8List(Uint8List bytes) String
Get the file extension directly from the bytes list. Throws an exception if the MIME type cannot be detected.