owlnext_dropzone library
Classes
- AbstractProgressUploadService
- Abstract service for handling chunk uploads with optional cancellation support. This is a fully abstract interface that doesn't depend on any HTTP client.
- BytesCalculation
- ClipboardFilesBypass
- CrossFileTestOverrides
- Overrides some functions of CrossFile for testing purposes
- DesktopDrop
- DocumentIconResolver
- Simple widget to show an icon depending on the file extension Example:
- DownloadFileWebBypass
- DropDoneDetails
- DropEventDetails
- DropItem
- DropItemDirectory
- DropItemFile
- DropTarget
- A widget that accepts draggable files.
- DropzoneTester
- DropzoneThemeData
- FakeHeavyUploadService
- Implémentation simplifiée d'un service d'upload fake pour les tests
- FileExceptionHandlingModel
- FileExtension
- FileExtensionStyling
- Configuration for a file type (icon and color) Example:
- FileExtensionStylingUtils
- Utility class for file type handling with override support
- FilePicker
- The interface that implementations of file_picker must implement.
- FilePickerIO
- An implementation of FilePicker that uses method channels.
- FilePickerLinux
- FilePickerMacOS
- FilePickerResult
- FilePickerWindows
- FileUtils
- HeavyFileUtils
- Utility class for handling heavy file uploads in chunks. Supports both web and non-web platforms with memory-efficient streaming. Provides progress tracking via callback. Requires an implementation of AbstractProgressUploadService for actual upload logic. Usage:
- HeavyUploadedFile
- MimeMultipart
- A Mime Multipart class representing each part parsed by MimeMultipartTransformer. The data is streamed in as it become available.
- MimeMultipartTransformer
- Parser for MIME multipart types of data as described in RFC 2046 section 5.1.1. The data is transformed into MimeMultipart objects, each of them streaming the multipart data.
- MimeTypeResolver
- MIME-type resolver class, used to customize the lookup of mime-types.
- OwlnextDropzone
- OwlnextDropzoneBuilderStateModel
- OwlnextDropzoneDebuger
- OwlnextDropzoneFileListBuilderStateModel
- OwlnextProgressDropzone
- OwlnextProgressDropzoneStyling
- OwlnextProgressDropzoneTranslations
- Classe de traduction pour le composant OwlnextProgressDropzone Permet de personnaliser tous les textes affichés dans l'interface
- PlatformFile
- XFile
- A CrossFile is a cross-platform, simplified File abstraction.
Enums
- DropZoneSize
- FilePickerStatus
- FileType
- OwlnextFileSize
-
Enumération utilitaire pour représenter des tailles de fichiers.
Permet d'accéder facilement à la valeur en octets (
inBytes) ou en mégaoctets (inMo).
Extensions
- BytesToFormatExtension on Uint8List
- Extension that allow dev to get file format directly from bytes
Constants
- defaultDialogTitle → const String
Properties
- defaultMagicNumbersMaxLength → int
-
The maximum number of bytes needed, to match all default magic-numbers.
no setter
Functions
-
extensionFromMime(
String mime) → String - Returns the extension for the given MIME type.
-
lookupMimeType(
String path, {List< int> ? headerBytes}) → String? -
Extract the extension from
pathand use that for MIME-type lookup, using the default extension map.
Typedefs
-
OnDragCallback<
Detail> = void Function(Detail details) - OnDragDoneCallback = void Function(DropDoneDetails details)
- RawDropListener = void Function(DropEvent)
Exceptions / Errors
- FileTooLargeException
- FileWrongDimensionsException
- FileWrongRatioException
- MimeMultipartException
- NotAllowedFileTypeException
- UploadCancelledException
- Custom exception for cancelled uploads