owlnext_dropzone library
Classes
- BytesCalculation
- ClipboardFilesBypass
- DocumentIconResolver
- Simple widget to show an icon depending on the file extension Example:
- DownloadFileWebBypass
- DropzoneTester
- DropzoneThemeData
- FileExceptionHandlingModel
- FileExtension
- FileExtensionStyling
- Configuration for a file type (icon and color) Example:
- FileExtensionStylingUtils
- Utility class for file type handling with override support
- FilePicker
- The interface that implementations of file_picker must implement.
- FilePickerResult
- FileUtils
- MimeMultipart
- A Mime Multipart class representing each part parsed by MimeMultipartTransformer. The data is streamed in as it become available.
- MimeMultipartTransformer
- Parser for MIME multipart types of data as described in RFC 2046 section 5.1.1. The data is transformed into MimeMultipart objects, each of them streaming the multipart data.
- MimeTypeResolver
- MIME-type resolver class, used to customize the lookup of mime-types.
- OwlnextDropzone
- OwlnextDropzoneBuilderStateModel
- OwlnextDropzoneDebuger
- OwlnextDropzoneFileListBuilderStateModel
- PlatformFile
Enums
- DropZoneSize
- FileType
- OwlnextFileSize
-
Enumération utilitaire pour représenter des tailles de fichiers.
Permet d'accéder facilement à la valeur en octets (
inBytes) ou en mégaoctets (inMo).
Extensions
- BytesToFormatExtension on Uint8List
- Extension that allow dev to get file format directly from bytes
Properties
- defaultMagicNumbersMaxLength → int
-
The maximum number of bytes needed, to match all default magic-numbers.
no setter
Functions
-
extensionFromMime(
String mime) → String - Returns the extension for the given MIME type.
-
lookupMimeType(
String path, {List< int> ? headerBytes}) → String? -
Extract the extension from
pathand use that for MIME-type lookup, using the default extension map.