OwlnextDropzoneBuilderStateModel class
Constructors
- OwlnextDropzoneBuilderStateModel({required bool enabled, required bool isMandatory, required bool isHovering, required bool isDragging, required Widget fileListWidget, required Widget? formStateErrorWidget, required String? formStateErrorText, required Widget? exceptionsWidget, required FileExceptionHandlingModel exceptionsModel})
Properties
- enabled → bool
-
If true, the dropzone is enabled (reinjected from OwlnextDropzone.enabled)
final
- exceptionsModel → FileExceptionHandlingModel
-
final
- exceptionsWidget → Widget?
-
The widget displaying the list of exceptions (if any)
final
- fileListWidget → Widget
-
The widget displaying the list of uploaded files (if no fileItemsBuilder is provided, will be default file list item preview)
final
- formStateErrorText → String?
-
final
- formStateErrorWidget → Widget?
-
If not null, contains the error message from the form state ("Merci de remplir ce champ", etc.)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDragging → bool
-
If true, the dropzone is currently being dragged over
final
- isHovering → bool
-
If true, the dropzone is currently being hovered over
final
- isMandatory → bool
-
If true, the dropzone is mandatory (reinjected from OwlnextDropzone.isMandatory)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited